@@ -1,7 +1,7 @@
 package Sah::Schema::currency::code;
 
-our $DATE = '2018-06-27'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-11-29'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use Locale::Codes::Currency_Codes ();
 
@@ -18,7 +18,7 @@ Accept only current (not retired) codes.
 _
     match => '\A[A-Z]{3}\z',
     in => $codes,
-    'x.perl.coerce_rules' => ['str_toupper'],
+    'x.perl.coerce_rules' => ['From_str::to_upper'],
 }, {}];
 
 1;
@@ -36,7 +36,7 @@ Sah::Schema::currency::code - Currency code
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2018-06-27.
+This document describes version 0.003 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
@@ -64,7 +64,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
